/*
 * jSite2 - NodeListener.java -
 * Copyright © 2008 David Roden
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

package net.pterodactylus.jsite.core;

import java.util.EventListener;

/**
 * Interface for listeners that want to be notified about node events.
 *
 * @author David ‘Bombe’ Roden &lt;bombe@freenetproject.org&gt;
 */
public interface NodeListener extends EventListener {

	/**
	 * Notifies a listener that a node was added.
	 *
	 * @param node
	 *            The node that was added
	 */
	public void nodeAdded(Node node);

	/**
	 * Notifies a listener that a node was removed.
	 *
	 * @param node
	 *            The node that was removed
	 */
	public void nodeRemoved(Node node);

	/**
	 * Notifies a listener that a connection to the given node was established.
	 *
	 * @param node
	 *            The node that is now connected
	 */
	public void nodeConnected(Node node);

	/**
	 * Notifies a listener that a connection to a node has failed.
	 *
	 * @param node
	 *            The node that could not be connected
	 * @param cause
	 *            The cause of the failure
	 */
	public void nodeConnectionFailed(Node node, Throwable cause);

	/**
	 * Notifies a listener that a connection to the given node was severed. If
	 * the listener needs the high-level client associated with the node for
	 * anything else (like deregistering as listener from it) it should retrieve
	 * the high-level client using {@link NodeManager#getHighLevelClient(Node)}
	 * before this method returns!
	 *
	 * @param node
	 *            The node that is now disconnected
	 * @param throwable
	 *            The exception that caused the disconnect, or <code>null</code>
	 *            if there was no exception
	 */
	public void nodeDisconnected(Node node, Throwable throwable);

}
