/*
 * jSite2 - RequestListener.java -
 * Copyright © 2008 David Roden
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

package net.pterodactylus.jsite.core;

import java.util.EventListener;

/**
 * Interface for objects that want to be notified on request events.
 *
 * @author David ‘Bombe’ Roden &lt;bombe@freenetproject.org&gt;
 */
public interface RequestListener extends EventListener {

	/**
	 * Notifies a listener that a request was added to a node.
	 *
	 * @param request
	 *            The request that was added
	 */
	public void requestAdded(Request request);

	/**
	 * Notifies a listener that a request made progress.
	 *
	 * @param request
	 *            The request
	 */
	public void requestProgressed(Request request);

	/**
	 * Notifies a listener that a request was removed.
	 *
	 * @param request
	 *            The request that was removed
	 */
	public void requestRemoved(Request request);

	/**
	 * Notifies a listener that a Put request has generated a URI.
	 *
	 * @param request
	 *            The request that generated a URI
	 * @param uri
	 *            The generated URI
	 */
	public void requestGeneratedURI(Request request, String uri);

	/**
	 * Notifies a listener that a request has completed.
	 *
	 * @param request
	 *            The finished request
	 */
	public void requestFinished(Request request);

}
